==> speech-analytic-testing_0.11.0_database.tar.gz: database/mssql/procedures/SaveUtterance.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- [dbo].[SaveUtterance] 'allegro', '4bad9174-ea84-45ee-ab2f-b17c73c43734', '45799dd8-17e7-49a1-9bd8-cb74f00a788c', '{f2c9e160-8eeb-11e9-8562-b65bb2fb6bcb}', 0, 1, 'in', 10, 14, 1.23, 1.38, 0, 'hola', '2019-08-02 15:30:00.000', 'analytic', NULL, NULL
CREATE PROCEDURE [dbo].[SaveUtterance]
(
	@VCC						VARCHAR(50),
	@AppId						VARCHAR(50),
	@IntentId					VARCHAR(50),
	@AudioId					VARCHAR(50),
	@Section					NUMERIC(5, 0),
	@Part						NUMERIC(5, 0),
	@Speaker					VARCHAR(3),
	@AnchorOffset				INT,
	@FocusOffset				INT,
	@CurrentTime				FLOAT,
	@EndCurrentTime				FLOAT,
	@UtteranceId				INT,
	@TextContent				VARCHAR(500),
	@CreatedDate				DATETIME,
	@CreatedByUserId			VARCHAR(50),
	@LastModifiedDate			DATETIME,
	@LastModifiedByUserId		VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	UPDATE [dbo].[Utterance] SET
		[VCC] = @VCC,
		[AppId] = @AppId,
		[IntentId] = @IntentId,
		[AudioId] = @AudioId,
		[Section] = @Section,
		[Part] = @Part,
		[Speaker] = @Speaker,
		[AnchorOffset] = @AnchorOffset,
		[FocusOffset] = @FocusOffset,
		[CurrentTime] = @CurrentTime,
		[EndCurrentTime] = @EndCurrentTime,
		[UtteranceId] = @UtteranceId,
		[TextContent] = @TextContent,
		[CreatedDate] = @CreatedDate,
		[CreatedByUserId] = @CreatedByUserId,
		[LastModifiedDate] = @LastModifiedDate,
		[LastModifiedByUserId] = @LastModifiedByUserId,
		[TimeStamp] = GETUTCDATE()
	WHERE
		[VCC] = @VCC
		AND [AppId] = @AppId
		AND [IntentId] = @IntentId
		AND [AudioId] = @AudioId
		AND [Section] = @Section
		AND [Part] = @Part
		AND [Speaker] = @Speaker
		AND [AnchorOffset] = @AnchorOffset
		AND [FocusOffset] = @FocusOffset
		AND [CurrentTime] = @CurrentTime
		AND [EndCurrentTime] = @EndCurrentTime
		AND [UtteranceId] = @UtteranceId
		AND [TextContent] = @TextContent

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [dbo].[Utterance] (
			[VCC],
			[AppId],
			[IntentId],
			[AudioId],
			[Section],
			[Part],
			[Speaker],
			[AnchorOffset],
			[FocusOffset],
			[CurrentTime],
			[EndCurrentTime],
			[UtteranceId],
			[TextContent],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp]
		)
		VALUES(
			@VCC,
			@AppId,
			@IntentId,
			@AudioId,
			@Section,
			@Part,
			@Speaker,
			@AnchorOffset,
			@FocusOffset,
			@CurrentTime,
			@EndCurrentTime,
			@UtteranceId,
			@TextContent,
			@CreatedDate,
			@CreatedByUserId,
			@LastModifiedDate,
			@LastModifiedByUserId,
			GETUTCDATE()
		)
	END

	SELECT 1 AS 'result'

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.16.1_database.tar.gz: database/mssql/procedures/SaveUtterance.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO
-- [dbo].[SaveUtterance] 'allegro', '4bad9174-ea84-45ee-ab2f-b17c73c43734', '45799dd8-17e7-49a1-9bd8-cb74f00a788c', '{f2c9e160-8eeb-11e9-8562-b65bb2fb6bcb}', 0, 1, 'in', 10, 14, 1.23, 1.38, 0, 'hola', '2019-08-02 15:30:00.000', 'analytic', NULL, NULL
CREATE PROCEDURE [dbo].[SaveUtterance]
(
	@VCC						VARCHAR(50),
	@AppId						VARCHAR(50),
	@IntentId					VARCHAR(50),
	@AudioId					VARCHAR(50),
	@Section					NUMERIC(5, 0),
	@Part						NUMERIC(5, 0),
	@Speaker					VARCHAR(3),
	@AnchorOffset				INT,
	@FocusOffset				INT,
	@CurrentTime				FLOAT,
	@EndCurrentTime				FLOAT,
	@UtteranceId				NUMERIC(18, 0),
	@TextContent				VARCHAR(500),
	@CreatedDate				DATETIME,
	@CreatedByUserId			VARCHAR(50),
	@LastModifiedDate			DATETIME,
	@LastModifiedByUserId		VARCHAR(50)
)
AS
BEGIN
	SET NOCOUNT ON

	-- EN CASO LLEGUE COMO NULL LO IGUALAMOS A 0
	IF @Section IS NULL BEGIN SET @Section = 0 END 

	UPDATE [dbo].[Utterance] SET
		[VCC] = @VCC,
		[AppId] = @AppId,
		[IntentId] = @IntentId,
		[AudioId] = @AudioId,
		[Section] = @Section,
		[Part] = @Part,
		[Speaker] = @Speaker,
		[AnchorOffset] = @AnchorOffset,
		[FocusOffset] = @FocusOffset,
		[CurrentTime] = @CurrentTime,
		[EndCurrentTime] = @EndCurrentTime,
		[UtteranceId] = @UtteranceId,
		[TextContent] = @TextContent,
		[CreatedDate] = @CreatedDate,
		[CreatedByUserId] = @CreatedByUserId,
		[LastModifiedDate] = @LastModifiedDate,
		[LastModifiedByUserId] = @LastModifiedByUserId,
		[TimeStamp] = GETUTCDATE()
	WHERE
		[VCC] = @VCC
		AND [AppId] = @AppId
		AND [IntentId] = @IntentId
		AND [AudioId] = @AudioId
		AND [Section] = @Section
		AND [Part] = @Part
		AND [Speaker] = @Speaker
		AND [AnchorOffset] = @AnchorOffset
		AND [FocusOffset] = @FocusOffset
		AND [CurrentTime] = @CurrentTime
		AND [EndCurrentTime] = @EndCurrentTime
		AND [UtteranceId] = @UtteranceId
		AND [TextContent] = @TextContent

	IF @@ROWCOUNT = 0
	BEGIN
		INSERT INTO [dbo].[Utterance] (
			[VCC],
			[AppId],
			[IntentId],
			[AudioId],
			[Section],
			[Part],
			[Speaker],
			[AnchorOffset],
			[FocusOffset],
			[CurrentTime],
			[EndCurrentTime],
			[UtteranceId],
			[TextContent],
			[CreatedDate],
			[CreatedByUserId],
			[LastModifiedDate],
			[LastModifiedByUserId],
			[TimeStamp]
		)
		VALUES(
			@VCC,
			@AppId,
			@IntentId,
			@AudioId,
			@Section,
			@Part,
			@Speaker,
			@AnchorOffset,
			@FocusOffset,
			@CurrentTime,
			@EndCurrentTime,
			@UtteranceId,
			@TextContent,
			@CreatedDate,
			@CreatedByUserId,
			@LastModifiedDate,
			@LastModifiedByUserId,
			GETUTCDATE()
		)
	END

	SELECT 1 AS 'result'

	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
